@@ -1,23 +1,23 @@
 __author__ = 'Nadeem Douba'
-__copyright__ = 'Copyright 2012, Canari Project'
+__copyright__ = 'Copyright 2015, Canari Project'
 __credits__ = []
 
-__license__ = 'GPL'
-__version__ = '1.1'
+__license__ = 'GPLv3'
+__version__ = '3.2.2'
 __maintainer__ = 'Nadeem Douba'
 __email__ = 'ndouba@gmail.com'
 __status__ = 'Development'
 
 __all__ = [
-    'commands',
     'maltego',
-    'pkgutils',
     'resources',
-    'tds',
     'utils',
-    'xmltools',
     'config',
     'easygui',
     'framework',
-    'resource'
-]
\ No newline at end of file
+    'mode',
+    'resource',
+    'tas',
+    'entrypoints'
+]
+
