@@ -1,11 +1,11 @@
 #!/usr/bin/env python2
 
 __author__ = 'Nadeem Douba'
-__copyright__ = 'Copyright 2012, Canari Project'
+__copyright__ = 'Copyright 2015, Canari Project'
 __credits__ = []
 
-__license__ = 'GPL'
-__version__ = '0.3'
+__license__ = 'GPLv3'
+__version__ = '0.1'
 __maintainer__ = 'Nadeem Douba'
 __email__ = 'ndouba@gmail.com'
 __status__ = 'Development'
@@ -18,20 +18,19 @@ __all__ = [
     'create_transform',
     'csv2sheets',
     'debug_transform',
-    'delete_transform',
+    'dockerize_package',
     'framework',
     'generate_entities',
     'help',
-    'install_package',
     'install_plume',
+    'list_transforms',
     'list_commands',
     'load_plume_package',
     'mtgx2csv',
-    'rename_transform',
-    'run_server',
     'run_transform',
     'shell',
-    'uninstall_package',
     'unload_plume_package',
-    'version'
+    'version',
+    'generate_entities_doc',
+    'remote_transform'
 ]
\ No newline at end of file
