@@ -1,17 +1,21 @@
-#!/usr/bin/env python2
+from __future__ import print_function
 
 import os
+import sys
+
+from canari.mode import CanariMode, set_canari_mode
 
 from canari.pkgutils.transform import TransformDistribution
-from common import canari_main, uproot, pushd
-from framework import SubCommand, Argument
+from canari.commands.common import canari_main, uproot
+from canari.commands.framework import SubCommand, Argument
+from canari.utils.fs import PushDir
 
 
 __author__ = 'Nadeem Douba'
 __copyright__ = 'Copyright 2012, Canari Project'
 __credits__ = []
 
-__license__ = 'GPL'
+__license__ = 'GPLv3'
 __version__ = '0.3'
 __maintainer__ = 'Nadeem Douba'
 __email__ = 'ndouba@gmail.com'
@@ -46,12 +50,14 @@ def parse_args(args):
 )
 def create_profile(args):
 
+    set_canari_mode(CanariMode.Local)
+
     opts = parse_args(args)
     current_dir = os.getcwd()
     try:
-        with pushd(opts.working_dir or current_dir):
+        with PushDir(opts.working_dir or current_dir):
             transform_package = TransformDistribution(opts.package)
             transform_package.create_profile(opts.working_dir, current_dir)
-    except ValueError, e:
-        print(str(e))
-        exit(-1)
\ No newline at end of file
+    except ValueError as e:
+        print(str(e), file=sys.stderr)
+        exit(-1)
