@@ -1,15 +1,13 @@
-#!/usr/bin/env python2
-
-from framework import SubCommand, Argument
-from common import canari_main
+from canari.commands.framework import SubCommand, Argument
+from canari.commands.common import canari_main
 
 
 __author__ = 'Nadeem Douba'
-__copyright__ = 'Copyright 2012, Canari Project'
+__copyright__ = 'Copyright 2015, Canari Project'
 __credits__ = []
 
-__license__ = 'GPL'
-__version__ = '0.3'
+__license__ = 'GPLv3'
+__version__ = '0.1'
 __maintainer__ = 'Nadeem Douba'
 __email__ = 'ndouba@gmail.com'
 __status__ = 'Development'
