@@ -1,14 +1,16 @@
-#!/usr/bin/env python2
+from __future__ import print_function
 
-from common import canari_main
+import sys
+
+from canari.commands.common import canari_main
 from canari.maltego.utils import highlight
-from framework import SubCommand
+from canari.commands.framework import SubCommand
 
 __author__ = 'Nadeem Douba'
 __copyright__ = 'Copyright 2012, Canari Project'
 __credits__ = []
 
-__license__ = 'GPL'
+__license__ = 'GPLv3'
 __version__ = '0.7'
 __maintainer__ = 'Nadeem Douba'
 __email__ = 'ndouba@gmail.com'
@@ -22,7 +24,5 @@ __status__ = 'Development'
 )
 def list_commands(opts):
     cmds = canari_main.subparsers.choices
-    k = cmds.keys()
-    k.sort()
-    for i in k:
-        print ('%s - %s' % (highlight(i, 'green', True), cmds[i].description))
\ No newline at end of file
+    for name, cmd in sorted(cmds.items()):
+        print('%s - %s' % (highlight(name, 'green', True), cmd.description), file=sys.stderr)
