@@ -1,17 +1,20 @@
-#!/usr/bin/env python2
+from __future__ import print_function
 
 import os
-from canari.pkgutils.transform import TransformDistribution
+import sys
 
-from common import canari_main
-from framework import SubCommand, Argument
+from canari.pkgutils.transform import TransformDistribution
+from canari.utils.fs import PushDir
+
+from canari.commands.common import canari_main
+from canari.commands.framework import SubCommand, Argument
 
 
 __author__ = 'Nadeem Douba'
 __copyright__ = 'Copyright 2012, Canari Project'
 __credits__ = []
 
-__license__ = 'GPL'
+__license__ = 'GPLv3'
 __version__ = '0.6'
 __maintainer__ = 'Nadeem Douba'
 __email__ = 'ndouba@gmail.com'
@@ -36,13 +39,14 @@ __status__ = 'Development'
     help='the path where Plume is installed.'
 )
 def unload_plume_package(opts):
-    if not os.path.exists(os.path.join(opts.plume_dir, 'plume.py')):
-        print('Plume does not appear to be installed in %s.' % opts.plume_dir)
-        exit(-1)
-
-    try:
-        TransformDistribution(opts.package).configure(opts.plume_dir, load=False, remote=True)
-    except ImportError:
-        pass
+    with PushDir(opts.plume_dir):
+        if not os.path.exists('canari.conf'):
+            print('Plume does not appear to be installed in %s.' % opts.plume_dir, file=sys.stderr)
+            print("Please run 'canari install-plume' and try again.", file=sys.stderr)
+            exit(-1)
+        try:
+            TransformDistribution(opts.package).configure(opts.plume_dir, load=False, remote=True)
+        except ImportError:
+            pass
 
     exit(0)
\ No newline at end of file
