@@ -1,7 +1,9 @@
-#!/usr/bin/env python2
+from __future__ import print_function
 
-from common import canari_main
-from framework import SubCommand
+import sys
+
+from canari.commands.common import canari_main
+from canari.commands.framework import SubCommand
 
 import canari
 
@@ -10,7 +12,7 @@ __author__ = 'Nadeem Douba'
 __copyright__ = 'Copyright 2012, Canari Project'
 __credits__ = []
 
-__license__ = 'GPL'
+__license__ = 'GPLv3'
 __version__ = '0.3'
 __maintainer__ = 'Nadeem Douba'
 __email__ = 'ndouba@gmail.com'
@@ -23,4 +25,5 @@ __status__ = 'Development'
     description='Show version of Canari framework that is currently active.'
 )
 def version(args):
-    print 'Your running *Canari Framework v%s*' % canari.__version__
\ No newline at end of file
+    print('Canari Framework v%s' % canari.__version__, file=sys.stderr)
+    print('Running on Python %s (%s)' % (sys.version, sys.executable))
