@@ -1,19 +1,15 @@
-#!/usr/bin/env python2
-
 __author__ = 'Nadeem Douba'
-__copyright__ = 'Copyright 2012, Canari Project'
+__copyright__ = 'Copyright 2015, Canari Project'
 __credits__ = []
 
-__license__ = 'GPL'
-__version__ = '0.2'
+__license__ = 'GPLv3'
+__version__ = '0.1'
 __maintainer__ = 'Nadeem Douba'
 __email__ = 'ndouba@gmail.com'
 __status__ = 'Development'
 
 __all__ = [
-    'configuration',
     'entities',
-    'html',
     'message',
-    'utils'
+    'transform'
 ]
\ No newline at end of file
