@@ -1,14 +1,17 @@
-#!/usr/bin/env python2
+from __future__ import print_function
 
 import os
 import re
 import sys
-import time
 import tempfile
-from zipfile import ZipFile, ZIP_STORED
+import time
 from distutils.version import LooseVersion
+from importlib import import_module
+from zipfile import ZipFile, ZIP_STORED
+
+from past.builtins import basestring
+from safedexml import Model
 
-from canari.commands.common import parse_int, get_bin_dir
 from canari.maltego.configuration import (TransformSettings, CmdLineTransformPropertySetting, InputConstraint, Set,
                                           CmdParmTransformPropertySetting, CmdCwdTransformPropertySetting,
                                           CmdDbgTransformPropertySetting, MaltegoTransform,
@@ -16,14 +19,14 @@ from canari.maltego.configuration import (TransformSettings, CmdLineTransformPro
                                           CmdParmTransformProperty, TransformSet, Transform, MaltegoServer, Protocol,
                                           Authentication, EntityCategory, Properties, attributes, fileobject, attr,
                                           MaltegoEntity)
-from safedexml import Model
-
+from canari.question import parse_int
+from canari.utils.common import find_dispatcher
 
 __author__ = 'Nadeem Douba'
 __copyright__ = 'Copyright 2012, Canari Project'
 __credits__ = ['Nadeem Douba']
 
-__license__ = 'GPL'
+__license__ = 'GPLv3'
 __version__ = '0.1'
 __maintainer__ = 'Nadeem Douba'
 __email__ = 'ndouba@gmail.com'
@@ -39,6 +42,7 @@ class MaltegoVersion:
     Radium = '3.2.0'
     Tungsten = '3.4.0'
     Carbon = '3.5.0'
+    Chlorine = '3.6.0'
 
 
 class MaltegoDistribution(object):
@@ -68,9 +72,9 @@ class MaltegoDistribution(object):
             path = os.path.join(dir_name, subdir_name)
         if not os.path.lexists(path):
             if create:
-                os.makedirs(path, 0755)
+                os.makedirs(path, 0o755)
             else:
-                raise OSError('Path does not exist: %s' % repr(path))
+                raise OSError('Path does not exist: %r' % path)
         return path
 
     @property
@@ -248,11 +252,11 @@ class MaltegoDistribution(object):
         if len(vs) == 1:
             return os.path.join(maltego_base_dir, vs[0])
         elif vs:
-            print('Multiple versions of Maltego detected: ')
+            print('Multiple versions of Maltego detected: ', file=sys.stderr)
             r = parse_int('Please select which version you wish to use', ['Maltego %s' % i for i in vs])
             return os.path.join(maltego_base_dir, vs[int(r)])
         print('Could not automatically find Maltego\'s settings directory. '
-              'Use the -w parameter to specify its location, instead.')
+              'Use the -w parameter to specify its location, instead.', file=sys.stderr)
 
     def _detect_settings_dir(self):
         if sys.platform.startswith('linux'):
@@ -263,7 +267,7 @@ class MaltegoDistribution(object):
             )
         elif sys.platform == 'win32':
             return self._iter_settings_dir(os.path.join(os.environ['APPDATA'], '.maltego'))
-        raise NotImplementedError('Unknown or unsupported OS: %s' % repr(sys.platform))
+        raise NotImplementedError('Unknown or unsupported OS: %r' % sys.platform)
 
     def add_transform_to_set(self, transform_id, transform_set):
         self.add_transform_set(transform_set)
@@ -276,72 +280,76 @@ class MaltegoDistribution(object):
         if not os.listdir(transform_set_dir):
             os.rmdir(transform_set_dir)
 
-    def add_transform(self, working_dir, transform_repository, transform, server=None):
-        name = transform.__name__
-        author = getattr(transform, '__author__', 'Canari Ninja')
-        spec = transform.dotransform
+    def _get_module_author(self, module_name):
+        return getattr(import_module(module_name), '__author__', '')
+
+    def add_transform(self, working_dir, transform_repository, transform_class, server=None):
         transform_repository_dir = self.get_transform_repository_dir(transform_repository)
 
-        for transform_id, (input_set, input_entity) in zip(spec.uuids, spec.inputs):
+        transform = transform_class()
+        name = '.'.join([transform_class.__module__, transform_class.__name__])
+        author = transform.author or self._get_module_author(transform.__module__)
+        transform_id = transform.name
+        input_set = transform.transform_set
+        input_entity = transform.input_type
 
-            if transform_id in self.transform_uuids:
-                print('WARNING: Previous declaration of %s in transform %s. Overwriting...' % (transform_id, name))
-            else:
-                print('Installing transform %s from %s...' % (transform_id, name))
+        if transform.name in self.transform_uuids:
+            print('WARNING: Previous declaration of %s in transform %s. Overwriting...' % (transform_id, name),
+                  file=sys.stderr)
+        else:
+            print('Installing transform %s from %s...' % (transform_id, name), file=sys.stderr)
 
-            sets = None
-            if input_set:
-                sets = Set(name=input_set)
-                self.add_transform_to_set(transform_id, input_set)
+        sets = None
+        if input_set:
+            sets = Set(name=input_set)
+            self.add_transform_to_set(transform_id, input_set)
 
-            if server:
-                self.add_transform_to_server(server, transform_id)
+        if server:
+            self.add_transform_to_server(server, transform_id)
 
-            transform_def = MaltegoTransform(
-                name=transform_id,
-                displayname=spec.label,
-                author=author,
-                description=spec.description,
-                properties=(
-                    Properties() +
-                    CmdLineTransformProperty() +
-                    CmdCwdTransformProperty() +
-                    CmdDbgTransformProperty() +
-                    CmdParmTransformProperty()
-                ),
-                input=[InputConstraint(type=input_entity._type_)],
-                sets=[sets]
-            )
+        transform_def = MaltegoTransform(
+            name=transform_id,
+            displayname=transform.display_name,
+            author=author,
+            description=transform.description,
+            properties=(
+                Properties() +
+                CmdLineTransformProperty() +
+                CmdCwdTransformProperty() +
+                CmdDbgTransformProperty() +
+                CmdParmTransformProperty()
+            ),
+            input=[InputConstraint(type=input_entity._type_)],
+            sets=[sets]
+        )
 
-            self.write_file(
-                self.path_join(transform_repository_dir, '%s.transform' % transform_id),
-                transform_def
-            )
+        self.write_file(
+            self.path_join(transform_repository_dir, '%s.transform' % transform_id),
+            transform_def
+        )
 
-            if not transform_def.sets:
-                print('WARNING: Transform does not appear to be part of any Transform Sets (Perhaps an error?).')
+        if not transform_def.sets:
+            print('WARNING: Transform does not appear to be part of any Transform Sets (Perhaps an error?).',
+                  file=sys.stderr)
 
-            transform_settings_def = TransformSettings(properties=[
-                CmdLineTransformPropertySetting(
-                    os.path.join(get_bin_dir(),
-                                 'dispatcher.bat' if os.name == 'nt' else 'dispatcher')
-                ),
-                CmdParmTransformPropertySetting(name),
-                CmdCwdTransformPropertySetting(working_dir),
-                CmdDbgTransformPropertySetting(spec.debug)
-            ])
+        transform_settings_def = TransformSettings(properties=[
+            CmdLineTransformPropertySetting(find_dispatcher()),
+            CmdParmTransformPropertySetting(name),
+            CmdCwdTransformPropertySetting(working_dir),
+            CmdDbgTransformPropertySetting(transform.debug)
+        ])
 
-            self.write_file(
-                self.path_join(transform_repository_dir, '%s.transformsettings' % transform_id),
-                transform_settings_def
-            )
+        self.write_file(
+            self.path_join(transform_repository_dir, '%s.transformsettings' % transform_id),
+            transform_settings_def
+        )
 
     def remove_transform(self, transform_repository, transform, server=None):
         spec = transform.dotransform
         transform_repository_dir = self.get_transform_repository_dir(transform_repository)
 
         for transform_id, (input_set, input_entity) in zip(spec.uuids, spec.inputs):
-            print 'Removing %s from %s...' % (transform_id, transform_repository_dir)
+            print('Removing %s from %s...' % (transform_id, transform_repository_dir), file=sys.stderr)
             self.remove_file(self.path_join(transform_repository_dir, '%s.transform' % transform_id))
             self.remove_file(self.path_join(transform_repository_dir, '%s.transformsettings' % transform_id))
             self.remove_transform_from_set(transform_id, input_set)
@@ -354,13 +362,13 @@ class MaltegoDistribution(object):
             return nbattr
         f = self.path_join(self.machines_dir, '.nbattrs')
         if os.path.exists(f):
-            data = file(f).read()
+            data = open(f).read()
             if data:
                 nbattr = nbattr.parse(data)
         return nbattr
 
     def _parse_machine_script(self, contents):
-        machine_sig = re.search('machine\s*\n*\((.+)\)\s*\n*\{\s*\n*start\s*\n*\{', contents, re.MULTILINE| re.DOTALL)
+        machine_sig = re.search('machine\s*\n*\((.+)\)\s*\n*{\s*\n*start\s*\n*{', contents, re.MULTILINE | re.DOTALL)
         if not machine_sig:
             return
         props = dict(re.findall(r'(?:(\w+)\s*:\s*)?["\']([^"\']+)["\']', machine_sig.groups()[0]))
@@ -374,7 +382,7 @@ class MaltegoDistribution(object):
         filename = os.path.basename(filename)
         name = filename.replace('.machine', '')
 
-        print 'Uninstalling %s from %s...' % (filename, self.machines_dir)
+        print('Uninstalling %s from %s...' % (filename, self.machines_dir), file=sys.stderr)
         if name in self._machine_nbattr.fileobjects:
             del self._machine_nbattr.fileobjects[name]
 
@@ -390,13 +398,13 @@ class MaltegoDistribution(object):
         if props['name'] not in self._machine_nbattr.fileobjects:
             f = fileobject(name=props['name'])
             self._machine_nbattr += f
-            for n, v in props.iteritems():
+            for n, v in props.items():
                 f += attr(name=n, stringvalue=v)
             f += attr(name='enabled', boolvalue=True)
             f += attr(name='readonly', boolvalue=False)
 
         dst = self.path_join(self.machines_dir, os.path.basename(filename))
-        print 'Installing machine %s to %s...' % (filename, dst)
+        print('Installing machine %s to %s...' % (filename, dst), file=sys.stderr)
         self.write_file(dst, contents)
 
     def add_entity(self, entity):
@@ -406,7 +414,7 @@ class MaltegoDistribution(object):
             raise TypeError('Expected str or MaltegoEntity, not %s', type(entity).__name__)
         entity_category_dir = self.get_entity_category_dir(entity.category)
         entity_filename = '%s.entity' % self.path_join(entity_category_dir, entity.id)
-        print 'Installing entity %s to %s...' % (entity.id, entity_filename)
+        print('Installing entity %s to %s...' % (entity.id, entity_filename), file=sys.stderr)
         self.write_file(entity_filename, entity.render(fragment=True, pretty=True))
 
     def path_join(self, *args):
@@ -416,7 +424,7 @@ class MaltegoDistribution(object):
         if self.version >= MaltegoVersion.Tungsten:
             raise NotImplementedError('This version of Maltego uses encrypted files and therefore does '
                                       'not support direct management of any files within the configuration directory.')
-        with file(filename, 'w') as f:
+        with open(filename, 'w') as f:
             if isinstance(contents, Model):
                 f.write(contents.render(fragment=True, pretty=True))
             else:
@@ -435,7 +443,7 @@ class MaltegoDistribution(object):
             os.unlink(filename)
 
     def __del__(self):
-        if self.version >= MaltegoVersion.Tungsten:
+        if not hasattr(self, '_version') or self.version >= MaltegoVersion.Tungsten:
             return
         self._write_pending()
 
@@ -469,17 +477,17 @@ class MtzZipFile(object):
                     namelist.append(self._get_archive_file(f_))
         return namelist
 
-    def writestr(self, zinfo_or_arcname, bytes):
+    def writestr(self, zinfo_or_arcname, bytes_):
         if self._is_closed:
             raise RuntimeError('Attempt to read ZIP archive that was already closed')
         if self.mode == 'r':
-            return self._zipfile.writestr(zinfo_or_arcname, bytes)
+            return self._zipfile.writestr(zinfo_or_arcname, bytes_)
         realpath = self._get_real_file(zinfo_or_arcname)
         realdir = os.path.dirname(realpath)
         if not os.path.isdir(realdir):
             os.makedirs(realdir)
-        with file(realpath, mode='wb') as f:
-            f.write(bytes)
+        with open(realpath, mode='w') as f:
+            f.write(bytes_)
 
     def removefile(self, zinfo_or_arcname):
         if self._is_closed:
@@ -495,7 +503,7 @@ class MtzZipFile(object):
             raise RuntimeError('Attempt to read ZIP archive that was already closed')
         if self.mode == 'r':
             return self._zipfile.read(name, pwd)
-        with file(self._get_real_file(name)) as f:
+        with open(self._get_real_file(name)) as f:
             return f.read()
 
     def _get_real_file(self, name):
@@ -701,17 +709,17 @@ class MtzDistribution(MtzZipFile, MaltegoDistribution):
 
     def _write_pending(self):
         # Write pending transform sets
-        for transform_set, transform_set_def in self._transform_sets.iteritems():
+        for transform_set, transform_set_def in self._transform_sets.items():
             transform_set_xml = TransformSet(
                 name=transform_set,
                 description=transform_set_def['description'],
                 transforms=[Transform(name=transform) for transform in transform_set_def['transforms']]
             )
-            print ('Writing transform set %s to %s...' % (transform_set, self.filename))
+            print('Writing transform set %s to %s...' % (transform_set, self.filename), file=sys.stderr)
             self.write_file(transform_set_def['filename'], transform_set_xml)
 
         # Write pending server definitions
-        for s, server_def in self._servers.iteritems():
+        for s, server_def in self._servers.items():
             server = MaltegoServer(
                 name=s,
                 enabled=server_def['enabled'],
@@ -722,7 +730,7 @@ class MtzDistribution(MtzZipFile, MaltegoDistribution):
                 authentication=Authentication(type_=server_def['authentication']),
                 transforms=[Transform(name=transform) for transform in server_def['transforms']]
             )
-            print('Writing server %s to %s' % (s, self.filename))
+            print('Writing server %s to %s' % (s, self.filename), file=sys.stderr)
             self.write_file(server_def['filename'], server)
 
     def add_server(self, server_name, **kwargs):
@@ -753,12 +761,12 @@ class MtzDistribution(MtzZipFile, MaltegoDistribution):
             self._servers[server_name]['transforms'].remove(transform_id)
 
     def add_machine(self, name, contents):
-        print 'Writing machine %s to %s...' % (name, self.filename)
+        print('Writing machine %s to %s...' % (name, self.filename), file=sys.stderr)
         self.write_file(self.path_join(self.machines_dir, name), contents)
         self.write_file(self.path_join(self.machines_dir, name.replace('.machine', '.properties')), 'enabled=true')
 
     def remove_machine(self, filename):
-        print 'Removing %s from %s...' % (filename, self.machines_dir)
+        print('Removing %s from %s...' % (filename, self.machines_dir), file=sys.stderr)
         path = self.path_join(self.machines_dir, os.path.basename(filename))
         self.remove_file(path)
         self.remove_file(path.replace('.machine', '.properties'))
@@ -770,7 +778,7 @@ class MtzDistribution(MtzZipFile, MaltegoDistribution):
         if not isinstance(mtz_file, MtzDistribution):
             raise TypeError('Expected MtzDistribution object got %s instead.' % type(mtz_file).__name__)
         for f in mtz_file.namelist():
-            print 'Writing %s to %s...' % (f, mtz_file.filename)
+            print('Writing %s to %s...' % (f, mtz_file.filename), file=sys.stderr)
             if re.match(r'.*?/(.+)?\.(entity|category|transform(settings)?|mtvs|properties|machine|seed)$', f):
                 self.write_file(f, mtz_file.read_file(f))
             elif f.endswith('.tas'):
@@ -785,7 +793,7 @@ class MtzDistribution(MtzZipFile, MaltegoDistribution):
             raise TypeError('Expected str or MaltegoEntity, not %s', type(entity).__name__)
         self.add_entity_category(entity.category)
         entity_filename = '%s.entity' % self.path_join(self.entities_dir, entity.id)
-        print 'Installing entity %s to %s...' % (entity.id, entity_filename)
+        print('Installing entity %s to %s...' % (entity.id, entity_filename), file=sys.stderr)
         self.write_file(entity_filename, entity.render(fragment=True, pretty=True))
 
     def path_join(self, *args):
