@@ -1,18 +1,14 @@
-#!/usr/bin/env python2
-
 __author__ = 'Nadeem Douba'
-__copyright__ = 'Copyright 2012, Canari Project'
+__copyright__ = 'Copyright 2015, Canari Project'
 __credits__ = []
 
-__license__ = 'GPL'
+__license__ = 'GPLv3'
 __version__ = '0.1'
 __maintainer__ = 'Nadeem Douba'
 __email__ = 'ndouba@gmail.com'
 __status__ = 'Development'
 
 __all__ = [
-    'images',
     'etc',
-    'tds',
     'template'
 ]
\ No newline at end of file
